@@ -23,7 +23,9 @@ SOFTWARE.
 
 __all__ = ['IAPWS95', 'IAPWS95Gas', 'IAPWS95Liquid', 'IAPWS97']
 
-from chemicals import iapws, mu_IAPWS, k_IAPWS
+from chemicals import iapws
+from chemicals.viscosity import mu_IAPWS
+from chemicals.thermal_conductivity import k_IAPWS
 from .helmholtz_eos import HelmholtzEOS
 from chemicals.utils import rho_to_Vm, Vm_to_rho
 from .phase import Phase
